@@ -24,8 +24,8 @@ You need to register the correct version listed in `Supported Resources`.
 |     ✅     | Dashboards              | `Datadog::Dashboards::Dashboard` | [Create, update, and delete Datadog dashboards.](https://github.com/DataDog/datadog-cloudformation-resources/tree/master/datadog-dashboards-dashboard-handler)      | [1.0.0](https://github.com/DataDog/datadog-cloudformation-resources/blob/master/datadog-dashboards-dashboard-handler/CHANGELOG.md#100--2021-02-16)         |
 |            | Datadog-AWS integration | `Datadog::Integrations::AWS`     | [Manage your Datadog-Amazon Web Service integration.](https://github.com/DataDog/datadog-cloudformation-resources/tree/master/datadog-integrations-aws-handler) | N/A                |
 |     ✅     | Monitors                | `Datadog::Monitors::Monitor`     | [Create, update, and delete Datadog monitors.](https://github.com/DataDog/datadog-cloudformation-resources/tree/master/datadog-monitors-monitor-handler)        | [3.0.0](https://github.com/DataDog/datadog-cloudformation-resources/blob/master/datadog-monitors-monitor-handler/CHANGELOG.md#300--2021-02-16)         |
-|            | Downtimes               | `Datadog::Monitors::Downtime`    | [Enable or disable downtimes for your monitors.](https://github.com/DataDog/datadog-cloudformation-resources/tree/master/datadog-monitors-downtime-handler)      | N/A                |
-|            | User                    | `Datadog::IAM::User`             | [ Create and manage Datadog users.](https://github.com/DataDog/datadog-cloudformation-resources/tree/master/datadog-iam-user-handler)                   | N/A                |
+|     ✅     | Downtimes               | `Datadog::Monitors::Downtime`    | [Enable or disable downtimes for your monitors.](https://github.com/DataDog/datadog-cloudformation-resources/tree/master/datadog-monitors-downtime-handler)      | [2.0.0](https://github.com/DataDog/datadog-cloudformation-resources/blob/master/datadog-monitors-downtime-handler/CHANGELOG.md#200--2021-02-16)         |
+|     ✅     | User                    | `Datadog::IAM::User`             | [Create and manage Datadog users.](https://github.com/DataDog/datadog-cloudformation-resources/tree/master/datadog-iam-user-handler)                    | [1.2.0](https://github.com/DataDog/datadog-cloudformation-resources/blob/master/datadog-iam-user-handler/CHANGELOG.md#120--2021-02-16)         |
 
 ## Installation
 
@@ -254,6 +254,444 @@ class DatadogDashboardProps:
         )
 
 
+class DatadogDowntime(
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@nomadblacky/cdk-datadog-resources.DatadogDowntime",
+):
+    '''Datadog Monitor Downtime 2.0.0.'''
+
+    def __init__(
+        self,
+        scope_: aws_cdk.core.Construct,
+        id_: builtins.str,
+        *,
+        datadog_credentials: DatadogCredentials,
+        scope: typing.Sequence[builtins.str],
+        active: typing.Optional[builtins.bool] = None,
+        canceled: typing.Optional[jsii.Number] = None,
+        creator_id: typing.Optional[jsii.Number] = None,
+        disabled: typing.Optional[builtins.bool] = None,
+        downtime_type: typing.Optional[jsii.Number] = None,
+        end: typing.Optional[jsii.Number] = None,
+        id: typing.Optional[jsii.Number] = None,
+        message: typing.Optional[builtins.str] = None,
+        monitor_id: typing.Optional[jsii.Number] = None,
+        monitor_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
+        parent_id: typing.Optional[jsii.Number] = None,
+        start: typing.Optional[jsii.Number] = None,
+        timezone: typing.Optional[builtins.str] = None,
+        updater_id: typing.Optional[jsii.Number] = None,
+    ) -> None:
+        '''
+        :param scope_: -
+        :param id_: -
+        :param datadog_credentials: Credentials for the Datadog API.
+        :param scope: The scope(s) to which the downtime applies.
+        :param active: Whether or not this downtime is currently active.
+        :param canceled: POSIX Timestamp of cancellation of this downtime (null if not canceled).
+        :param creator_id: Id of the user who created this downtime.
+        :param disabled: Whether or not this downtime is disabled.
+        :param downtime_type: Type of this downtime.
+        :param end: POSIX timestamp to end the downtime. If not provided, the downtime is in effect indefinitely (i.e. until you cancel it).
+        :param id: Id of this downtime.
+        :param message: Message on the downtime.
+        :param monitor_id: A single monitor to which the downtime applies. If not provided, the downtime applies to all monitors.
+        :param monitor_tags: A comma-separated list of monitor tags, to which the downtime applies. The resulting downtime applies to monitors that match ALL provided monitor tags.
+        :param parent_id: The ID of the parent downtime to this one.
+        :param start: POSIX timestamp to start the downtime. If not provided, the downtime starts the moment it is created.
+        :param timezone: The timezone for the downtime.
+        :param updater_id: Id of the user who updated this downtime.
+        '''
+        props = DatadogDowntimeProps(
+            datadog_credentials=datadog_credentials,
+            scope=scope,
+            active=active,
+            canceled=canceled,
+            creator_id=creator_id,
+            disabled=disabled,
+            downtime_type=downtime_type,
+            end=end,
+            id=id,
+            message=message,
+            monitor_id=monitor_id,
+            monitor_tags=monitor_tags,
+            parent_id=parent_id,
+            start=start,
+            timezone=timezone,
+            updater_id=updater_id,
+        )
+
+        jsii.create(DatadogDowntime, self, [scope_, id_, props])
+
+
+@jsii.data_type(
+    jsii_type="@nomadblacky/cdk-datadog-resources.DatadogDowntimeProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "datadog_credentials": "datadogCredentials",
+        "scope": "scope",
+        "active": "active",
+        "canceled": "canceled",
+        "creator_id": "creatorId",
+        "disabled": "disabled",
+        "downtime_type": "downtimeType",
+        "end": "end",
+        "id": "id",
+        "message": "message",
+        "monitor_id": "monitorId",
+        "monitor_tags": "monitorTags",
+        "parent_id": "parentId",
+        "start": "start",
+        "timezone": "timezone",
+        "updater_id": "updaterId",
+    },
+)
+class DatadogDowntimeProps:
+    def __init__(
+        self,
+        *,
+        datadog_credentials: DatadogCredentials,
+        scope: typing.Sequence[builtins.str],
+        active: typing.Optional[builtins.bool] = None,
+        canceled: typing.Optional[jsii.Number] = None,
+        creator_id: typing.Optional[jsii.Number] = None,
+        disabled: typing.Optional[builtins.bool] = None,
+        downtime_type: typing.Optional[jsii.Number] = None,
+        end: typing.Optional[jsii.Number] = None,
+        id: typing.Optional[jsii.Number] = None,
+        message: typing.Optional[builtins.str] = None,
+        monitor_id: typing.Optional[jsii.Number] = None,
+        monitor_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
+        parent_id: typing.Optional[jsii.Number] = None,
+        start: typing.Optional[jsii.Number] = None,
+        timezone: typing.Optional[builtins.str] = None,
+        updater_id: typing.Optional[jsii.Number] = None,
+    ) -> None:
+        '''
+        :param datadog_credentials: Credentials for the Datadog API.
+        :param scope: The scope(s) to which the downtime applies.
+        :param active: Whether or not this downtime is currently active.
+        :param canceled: POSIX Timestamp of cancellation of this downtime (null if not canceled).
+        :param creator_id: Id of the user who created this downtime.
+        :param disabled: Whether or not this downtime is disabled.
+        :param downtime_type: Type of this downtime.
+        :param end: POSIX timestamp to end the downtime. If not provided, the downtime is in effect indefinitely (i.e. until you cancel it).
+        :param id: Id of this downtime.
+        :param message: Message on the downtime.
+        :param monitor_id: A single monitor to which the downtime applies. If not provided, the downtime applies to all monitors.
+        :param monitor_tags: A comma-separated list of monitor tags, to which the downtime applies. The resulting downtime applies to monitors that match ALL provided monitor tags.
+        :param parent_id: The ID of the parent downtime to this one.
+        :param start: POSIX timestamp to start the downtime. If not provided, the downtime starts the moment it is created.
+        :param timezone: The timezone for the downtime.
+        :param updater_id: Id of the user who updated this downtime.
+        '''
+        if isinstance(datadog_credentials, dict):
+            datadog_credentials = DatadogCredentials(**datadog_credentials)
+        self._values: typing.Dict[str, typing.Any] = {
+            "datadog_credentials": datadog_credentials,
+            "scope": scope,
+        }
+        if active is not None:
+            self._values["active"] = active
+        if canceled is not None:
+            self._values["canceled"] = canceled
+        if creator_id is not None:
+            self._values["creator_id"] = creator_id
+        if disabled is not None:
+            self._values["disabled"] = disabled
+        if downtime_type is not None:
+            self._values["downtime_type"] = downtime_type
+        if end is not None:
+            self._values["end"] = end
+        if id is not None:
+            self._values["id"] = id
+        if message is not None:
+            self._values["message"] = message
+        if monitor_id is not None:
+            self._values["monitor_id"] = monitor_id
+        if monitor_tags is not None:
+            self._values["monitor_tags"] = monitor_tags
+        if parent_id is not None:
+            self._values["parent_id"] = parent_id
+        if start is not None:
+            self._values["start"] = start
+        if timezone is not None:
+            self._values["timezone"] = timezone
+        if updater_id is not None:
+            self._values["updater_id"] = updater_id
+
+    @builtins.property
+    def datadog_credentials(self) -> DatadogCredentials:
+        '''Credentials for the Datadog API.'''
+        result = self._values.get("datadog_credentials")
+        assert result is not None, "Required property 'datadog_credentials' is missing"
+        return typing.cast(DatadogCredentials, result)
+
+    @builtins.property
+    def scope(self) -> typing.List[builtins.str]:
+        '''The scope(s) to which the downtime applies.'''
+        result = self._values.get("scope")
+        assert result is not None, "Required property 'scope' is missing"
+        return typing.cast(typing.List[builtins.str], result)
+
+    @builtins.property
+    def active(self) -> typing.Optional[builtins.bool]:
+        '''Whether or not this downtime is currently active.'''
+        result = self._values.get("active")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
+    @builtins.property
+    def canceled(self) -> typing.Optional[jsii.Number]:
+        '''POSIX Timestamp of cancellation of this downtime (null if not canceled).'''
+        result = self._values.get("canceled")
+        return typing.cast(typing.Optional[jsii.Number], result)
+
+    @builtins.property
+    def creator_id(self) -> typing.Optional[jsii.Number]:
+        '''Id of the user who created this downtime.'''
+        result = self._values.get("creator_id")
+        return typing.cast(typing.Optional[jsii.Number], result)
+
+    @builtins.property
+    def disabled(self) -> typing.Optional[builtins.bool]:
+        '''Whether or not this downtime is disabled.'''
+        result = self._values.get("disabled")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
+    @builtins.property
+    def downtime_type(self) -> typing.Optional[jsii.Number]:
+        '''Type of this downtime.'''
+        result = self._values.get("downtime_type")
+        return typing.cast(typing.Optional[jsii.Number], result)
+
+    @builtins.property
+    def end(self) -> typing.Optional[jsii.Number]:
+        '''POSIX timestamp to end the downtime.
+
+        If not provided, the downtime is in effect indefinitely (i.e. until you cancel it).
+        '''
+        result = self._values.get("end")
+        return typing.cast(typing.Optional[jsii.Number], result)
+
+    @builtins.property
+    def id(self) -> typing.Optional[jsii.Number]:
+        '''Id of this downtime.'''
+        result = self._values.get("id")
+        return typing.cast(typing.Optional[jsii.Number], result)
+
+    @builtins.property
+    def message(self) -> typing.Optional[builtins.str]:
+        '''Message on the downtime.'''
+        result = self._values.get("message")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def monitor_id(self) -> typing.Optional[jsii.Number]:
+        '''A single monitor to which the downtime applies.
+
+        If not provided, the downtime applies to all monitors.
+        '''
+        result = self._values.get("monitor_id")
+        return typing.cast(typing.Optional[jsii.Number], result)
+
+    @builtins.property
+    def monitor_tags(self) -> typing.Optional[typing.List[builtins.str]]:
+        '''A comma-separated list of monitor tags, to which the downtime applies.
+
+        The resulting downtime applies to monitors that match ALL provided monitor tags.
+        '''
+        result = self._values.get("monitor_tags")
+        return typing.cast(typing.Optional[typing.List[builtins.str]], result)
+
+    @builtins.property
+    def parent_id(self) -> typing.Optional[jsii.Number]:
+        '''The ID of the parent downtime to this one.'''
+        result = self._values.get("parent_id")
+        return typing.cast(typing.Optional[jsii.Number], result)
+
+    @builtins.property
+    def start(self) -> typing.Optional[jsii.Number]:
+        '''POSIX timestamp to start the downtime.
+
+        If not provided, the downtime starts the moment it is created.
+        '''
+        result = self._values.get("start")
+        return typing.cast(typing.Optional[jsii.Number], result)
+
+    @builtins.property
+    def timezone(self) -> typing.Optional[builtins.str]:
+        '''The timezone for the downtime.'''
+        result = self._values.get("timezone")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def updater_id(self) -> typing.Optional[jsii.Number]:
+        '''Id of the user who updated this downtime.'''
+        result = self._values.get("updater_id")
+        return typing.cast(typing.Optional[jsii.Number], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "DatadogDowntimeProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
+class DatadogIAMUser(
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@nomadblacky/cdk-datadog-resources.DatadogIAMUser",
+):
+    '''Datadog Application User 1.2.0.'''
+
+    def __init__(
+        self,
+        scope: aws_cdk.core.Construct,
+        id: builtins.str,
+        *,
+        datadog_credentials: DatadogCredentials,
+        access_role: typing.Optional[builtins.str] = None,
+        disabled: typing.Optional[builtins.bool] = None,
+        email: typing.Optional[builtins.str] = None,
+        handle: typing.Optional[builtins.str] = None,
+        name: typing.Optional[builtins.str] = None,
+        verified: typing.Optional[builtins.bool] = None,
+    ) -> None:
+        '''
+        :param scope: -
+        :param id: -
+        :param datadog_credentials: Credentials for the Datadog API.
+        :param access_role: The role of the user.
+        :param disabled: Whether or not the user is disabled.
+        :param email: User email.
+        :param handle: User handle (a valid email).
+        :param name: User name.
+        :param verified: Whether or not the user is verified.
+        '''
+        props = DatadogIAMUserProps(
+            datadog_credentials=datadog_credentials,
+            access_role=access_role,
+            disabled=disabled,
+            email=email,
+            handle=handle,
+            name=name,
+            verified=verified,
+        )
+
+        jsii.create(DatadogIAMUser, self, [scope, id, props])
+
+
+@jsii.data_type(
+    jsii_type="@nomadblacky/cdk-datadog-resources.DatadogIAMUserProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "datadog_credentials": "datadogCredentials",
+        "access_role": "accessRole",
+        "disabled": "disabled",
+        "email": "email",
+        "handle": "handle",
+        "name": "name",
+        "verified": "verified",
+    },
+)
+class DatadogIAMUserProps:
+    def __init__(
+        self,
+        *,
+        datadog_credentials: DatadogCredentials,
+        access_role: typing.Optional[builtins.str] = None,
+        disabled: typing.Optional[builtins.bool] = None,
+        email: typing.Optional[builtins.str] = None,
+        handle: typing.Optional[builtins.str] = None,
+        name: typing.Optional[builtins.str] = None,
+        verified: typing.Optional[builtins.bool] = None,
+    ) -> None:
+        '''
+        :param datadog_credentials: Credentials for the Datadog API.
+        :param access_role: The role of the user.
+        :param disabled: Whether or not the user is disabled.
+        :param email: User email.
+        :param handle: User handle (a valid email).
+        :param name: User name.
+        :param verified: Whether or not the user is verified.
+        '''
+        if isinstance(datadog_credentials, dict):
+            datadog_credentials = DatadogCredentials(**datadog_credentials)
+        self._values: typing.Dict[str, typing.Any] = {
+            "datadog_credentials": datadog_credentials,
+        }
+        if access_role is not None:
+            self._values["access_role"] = access_role
+        if disabled is not None:
+            self._values["disabled"] = disabled
+        if email is not None:
+            self._values["email"] = email
+        if handle is not None:
+            self._values["handle"] = handle
+        if name is not None:
+            self._values["name"] = name
+        if verified is not None:
+            self._values["verified"] = verified
+
+    @builtins.property
+    def datadog_credentials(self) -> DatadogCredentials:
+        '''Credentials for the Datadog API.'''
+        result = self._values.get("datadog_credentials")
+        assert result is not None, "Required property 'datadog_credentials' is missing"
+        return typing.cast(DatadogCredentials, result)
+
+    @builtins.property
+    def access_role(self) -> typing.Optional[builtins.str]:
+        '''The role of the user.'''
+        result = self._values.get("access_role")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def disabled(self) -> typing.Optional[builtins.bool]:
+        '''Whether or not the user is disabled.'''
+        result = self._values.get("disabled")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
+    @builtins.property
+    def email(self) -> typing.Optional[builtins.str]:
+        '''User email.'''
+        result = self._values.get("email")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def handle(self) -> typing.Optional[builtins.str]:
+        '''User handle (a valid email).'''
+        result = self._values.get("handle")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def name(self) -> typing.Optional[builtins.str]:
+        '''User name.'''
+        result = self._values.get("name")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def verified(self) -> typing.Optional[builtins.bool]:
+        '''Whether or not the user is verified.'''
+        result = self._values.get("verified")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "DatadogIAMUserProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 class DatadogMonitor(
     metaclass=jsii.JSIIMeta,
     jsii_type="@nomadblacky/cdk-datadog-resources.DatadogMonitor",
@@ -777,6 +1215,10 @@ __all__ = [
     "DatadogCredentials",
     "DatadogDashboard",
     "DatadogDashboardProps",
+    "DatadogDowntime",
+    "DatadogDowntimeProps",
+    "DatadogIAMUser",
+    "DatadogIAMUserProps",
     "DatadogMonitor",
     "DatadogMonitorProps",
     "MonitorOptions",
